:mod:`art.estimators.generation`
================================
.. automodule:: art.estimators.generation

Mixin Base Class Generator
--------------------------
.. autoclass:: GeneratorMixin
   :members:

TensorFlow Generator
--------------------
.. autoclass:: TensorFlowGenerator
   :members:
   :special-members: __init__
   :inherited-members:
